@@ -7,13 +7,12 @@ with 'MooseX::Storage::Deferred';
 use Message::Stack;
 use Message::Stack::DataVerifier;
 
-our $VERSION = '0.03';
+our $VERSION = '0.04';
 
 has 'messages' => (
     is => 'ro',
     isa => 'Message::Stack',
-    default => sub { Message::Stack->new },
-    lazy => 1,
+    lazy_build => 1,
     handles => {
         'messages_for_scope' => 'for_scope',
     }
@@ -46,14 +45,20 @@ has 'verifiers' => (
     }
 );
 
-sub success {
+sub _build_messages {
     my ($self) = @_;
 
-    foreach my $res (keys %{ $self->results }) {
-        return 0 unless $self->get_results($res)->success;
+    # We lazily build the messages to avoid parsing the results until the last
+    # possible moment.  This lets the user fiddle with the results if they
+    # want.
+
+    my $stack = Message::Stack->new;
+    foreach my $scope (keys %{ $self->results }) {
+        my $results = $self->get_results($scope);
+        Message::Stack::DataVerifier->parse($stack, $scope, $results);
     }
 
-    return 1;
+    return $stack;
 }
 
 sub verify {
@@ -65,8 +70,6 @@ sub verify {
     my $results = $verifier->verify($data);
     $self->set_results($scope, $results);
 
-    Message::Stack::DataVerifier->parse($self->messages, $scope, $results);
-
     return $results;
 }
 
@@ -151,7 +154,10 @@ attribute to be set to undefined, as those objects are not serializable>.
 
 =head2 messages
 
-The L<Message::Stack> object for this manager.
+The L<Message::Stack> object for this manager.  This attribute is lazily
+populated, parsing the L<Data::Verifier::Results> objects.  After fetching
+this attribute any changes to the results B<will not be reflected in the
+message stack>.
 
 =head2 results
 
@@ -168,11 +174,6 @@ HashRef of L<Data::Verifier> objects, keyed by scope.
 Returns a L<Message::Stack> object containing messages for the specified
 scope.
 
-=head2 success
-
-Convenience method that checks C<success> on each of the results in this
-manager.  Returns false if any are false. 
-
 =head2 verify ($scope, $data);
 
 Verify the data against the specified scope.  After verification the results
